@@ -553,7 +553,7 @@ static int blb_protocol_decode_query(
       h->hsensorid = mpack_expect_bool(rd);
     } else {
       L(log_error(
-          "invalid inner message: unkown key: `%.*s`", (int)key_len, key));
+          "invalid inner message: unknown key: `%.*s`", (int)key_len, key));
       goto decode_error;
     }
   }
@@ -898,4 +898,4 @@ void blb_protocol_log_query(const protocol_query_request_t* q) {
       (int)q->qsensorid_len,
       q->qsensorid,
       q->limit);
-}
\ No newline at end of file
+}
